TideQuickPickItem class

Constructors

TideQuickPickItem({required String label, IconData? leadingIcon, bool showSeparator = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
The label to display for the item.
final
leadingIcon IconData?
An icon to display to the left of the label.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showSeparator bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited