TideTimeState class

The state that is output in the stream by TideTimeService.

Constructors

TideTimeState(DateTime now)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
now DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

formatted(String pattern) String
Formats the current time according to the given pattern using intl.DateFormat.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
timeFormatted({bool use24HourFormat = false}) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited