TideTogglePanelVisibilityContribution class

Contributes a command that toggles the visibility of a panel.

Inheritance

Constructors

TideTogglePanelVisibilityContribution({required TideId commandId, required TideId panelId})

Properties

commandId TideId
final
hashCode int
The hash code for this object.
no setterinherited
panelId TideId
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerCommands(TideCommandRegistry registry) → void
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited