TideWorkbenchService class

The workbench service that is created when Tide is initialized. To use a different workbench service, create a class that extends TideWorkbenchService and register it before Tide is initialized. There should only be one workbench service.

Constructors

TideWorkbenchService()

Properties

accessor ↔ TideServicesAccessor
The accessor instance for this workbench.
latefinal
builderRegistery → TideBuilderRegistery
final
hashCode → int
The hash code for this object.
no setterinherited
layoutService → TideWorkbenchLayoutService
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited