TideTogglePanelVisibilityContribution class
Contributes a command that toggles the visibility of a panel.
- Inheritance
-
- Object
- TideCommandContribution
- TideTogglePanelVisibilityContribution
Constructors
- TideTogglePanelVisibilityContribution({required TideId commandId, required TideId panelId})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerCommands(
TideCommandRegistry registry) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited